# Hosker Utils

This repository defines a PIP package defining some **utility functions** of
general application.

## Install HMSS

To install His Majesty's Software Suite:

1. Run `pip install --break-system-packages .` in this directory.
1. Run `install-hmss`.
